@@ -554,7 +554,7 @@ GSS_CALLCONV gss_init_sec_context(
 
     gss_delete_sec_context(&local_minor_status, 
                            (gss_ctx_id_t *) &context,
-                           output_token);
+                           output_token->length == 0 ? output_token : GSS_C_NO_BUFFER);
     *context_handle_P = (gss_ctx_id_t) context;
  
  exit:
